@@ -4,18 +4,17 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.010001'; # VERSION
+our $VERSION = '0.010002'; # VERSION
 
 use Moose;
-use Module::Runtime  qw( use_module );
-use Type::Params     qw( compile    );
+use Module::Runtime  qw( use_module       );
+use Type::Params     qw( compile Invocant );
 use Types::Standard  qw( HashRef Optional );
-use Type::Utils      qw( class_type role_type );
+use Type::Utils      qw( role_type        );
 
 sub create { ## no critic ( RequireArgUnpacking )
-	state $class     = class_type { class => __PACKAGE__ };
 	state $traceable = role_type 'Business::CyberSource::Role::Traceable';
-	state $check     = compile( $class, HashRef, Optional[$traceable]);
+	state $check     = compile( Invocant, HashRef, Optional[$traceable]);
 	my ( $self, $result , $request ) = $check->( @_ );
 
 	$result->{http_trace}
@@ -45,7 +44,7 @@ Business::CyberSource::Factory::Response - A Response Factory
 
 =head1 VERSION
 
-version 0.010001
+version 0.010002
 
 =head1 METHODS
 
